#encoding=utf-8
require './lib/pick_ja_date.rb'
require 'yaml'

describe PickJaDate do
  def format_time(time)
    time.strftime '%Y/%m/%d %H:%M'
  end

  before do
    Time.stub(:now).and_return(Time.parse('2011/10/10 10:10:00')) # monday
    @now = Time.now
  end

  yml = YAML.load <<-YML
  土曜の15 時半に地下鉄にのる:    2011/10/15 15:30
  土曜 15時半 地下鉄にのる:       2011/10/15 15:30
  地下鉄にのる土曜の15時半に:     2011/10/15 15:30
  次の土曜の15時半に地下鉄にのる: 2011/10/15 15:30

  明日地下鉄にのる:               2011/10/11 10:10
  あしたの15:00に地下鉄にのる:    2011/10/11 15:00
  明後日の15:00に地下鉄にのる:    2011/10/12 15:00

  3時間後に地下鉄にのる:          2011/10/10 13:10
  3日後に地下鉄にのる:            2011/10/13 10:10
  3週間後に地下鉄にのる:          2011/10/31 10:10
  1月後に地下鉄にのる:            2011/11/10 10:10
  1ヶ月後に地下鉄にのる:          2011/11/10 10:10

  12/10 10:00に地下鉄にのる:      2011/12/10 10:00
  2011/12/10 10:00に地下鉄にのる: 2011/12/10 10:00
  2012/12/10 10:00に地下鉄にのる: 2012/12/10 10:00
  9/10 18:00に地下鉄にのる:       2012/09/10 18:00

  3日後の1時に地下鉄にのる:       2011/10/13 01:00
  3日後の25時に地下鉄にのる:      2011/10/14 01:00
  あと30分で地下鉄にのる:         2011/10/10 10:40

  月末の13:00に地下鉄にのる:      2011/10/31 13:00
  1日の13:00に地下鉄にのる:       2011/11/01 13:00
  月初の13:00に地下鉄にのる:      2011/11/01 13:00
  来月の3日の13:00に地下鉄にのる:   2011/11/03 13:00
  再来月の3日の13:00に地下鉄にのる: 2011/12/03 13:00
  三ヶ月後の3日の13:00に地下鉄にのる: 2012/01/03 13:00
  YML

  describe "日付を解析できる" do
    yml.each do|text,time|
      it "#{text}" do
        r_time,r_text = PickJaDate.extract(text.dup)
        expect(format_time(r_time)).to eq(time)
        expect(r_text).to eq('地下鉄にのる')
        expect(format_time(PickJaDate.date(text.dup))).to eq(time)
      end
    end
  end
end
